@@ -1,9 +1,8 @@
 import inspect
-from src.unitgrade2.unitgrade2 import methodsWithDecorator, hide
+from unitgrade2.unitgrade2 import methodsWithDecorator, hide
 import os
 import importlib
 
-
 def remove_hidden_methods(ReportClass, outfile=None):
     # Given a ReportClass, clean out all @hidden tests from the imports of that class.
     file = ReportClass()._file()
@@ -13,7 +12,9 @@ def remove_hidden_methods(ReportClass, outfile=None):
     lines_to_rem = []
 
     for Q,_ in ReportClass.questions:
+        print(Q)
         ls = list(methodsWithDecorator(Q, hide))
+        print("hide decorateed is", ls)
         for f in ls:
             s, start = inspect.getsourcelines(f)
             end = len(s) + start
