@@ -1,4 +1,4 @@
-from src.unitgrade2 import unitgrade_helpers2
+from unitgrade2 import unitgrade_helpers2
 import jinja2
 import pickle
 import inspect
@@ -48,7 +48,6 @@ def setup_answers(report):
         #     payloads[q.name][item.name] = {'payload': answer, 'precomputed': item._precomputed_payload, 'time': time.time() - start, 'title': item.title}
 
     print(tabulate.tabulate(rs, headers="keys"))
-    # from src.unitgrade2 import cache_write, unitgrade_helpers2
     # cache_write(payloads, report.computed_answers_file, verbose=False)
 
 
@@ -120,14 +119,17 @@ def setup_grade_file_report(ReportClass, execute=False, obfuscate=False, minify=
     with open(output, 'w', encoding="utf-8") as f:
         f.write(s)
 
-    if minify:  # obfuscate:
+    if minify or bzip:  # obfuscate:
         obs = '-O ' if obfuscate else ""
         # output_obfuscated = output[:-3]+"_obfuscated.py"
         extra = [  # "--nonlatin",
             # '--bzip2',
         ]
         if bzip: extra.append("--bzip2")
-        cmd = f'pyminifier {obs} {" ".join(extra)} --replacement-length=20 -o {output} {output}'
+        if minify:
+            obs += " --replacement-length=20"
+
+        cmd = f'pyminifier {obs} {" ".join(extra)} -o {output} {output}'
         print(cmd)
         os.system(cmd)
         import time
